@@ -134,9 +134,18 @@ class Comm(ABC):
 
     @staticmethod
     def handshake_configuration(local, remote):
-        out = {
-            "pickle-protocol": min(local["pickle-protocol"], remote["pickle-protocol"])
-        }
+        try:
+            out = {
+                "pickle-protocol": min(
+                    local["pickle-protocol"], remote["pickle-protocol"]
+                )
+            }
+        except KeyError:
+            raise ValueError(
+                "Your Dask versions may not be in sync. "
+                "Please ensure that you have the same version of dask "
+                "and distributed on your client, scheduler, and worker machines"
+            )
 
         if local["compression"] == remote["compression"]:
             out["compression"] = local["compression"]
@@ -209,10 +218,10 @@ class Listener(ABC):
             handshake = await asyncio.wait_for(comm.read(), 1)
             # This would be better, but connections leak if worker is closed quickly
             # write, handshake = await asyncio.gather(comm.write(local_info), comm.read())
-        except Exception:
+        except Exception as e:
             with suppress(Exception):
                 await comm.close()
-            raise CommClosedError()
+            raise CommClosedError() from e
 
         comm.remote_info = handshake
         comm.remote_info["address"] = comm._peer_addr
@@ -289,10 +298,10 @@ async def connect(
                         write = await asyncio.wait_for(comm.write(local_info), 1)
                         # This would be better, but connections leak if worker is closed quickly
                         # write, handshake = await asyncio.gather(comm.write(local_info), comm.read())
-                    except Exception:
+                    except Exception as e:
                         with suppress(Exception):
                             await comm.close()
-                        raise CommClosedError()
+                        raise CommClosedError() from e
 
                     comm.remote_info = handshake
                     comm.remote_info["address"] = comm._peer_addr
